pub trait Clear {
// Required method
fn clear(&mut self);
}Expand description
A type that can remove its contents and return to an empty state.
Generally, this method does not release resources, and is used to make the container available for re-insertion.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".