pub struct Chars<CV = Vec<u32>> {
pub values: CV,
}Fields
values: CVTrait Implementations
Sourceimpl<CV: BorrowIndexAs<u32>> Borrow for Chars<CV>
impl<CV: BorrowIndexAs<u32>> Borrow for Chars<CV>
Sourcetype Borrowed<'a> = Chars<<CV as Borrow>::Borrowed<'a>>
where
CV: 'a
type Borrowed<'a> = Chars<<CV as Borrow>::Borrowed<'a>> where CV: 'a
The type of a borrowed container. Read more
Sourcefn borrow<'a>(&'a self) -> Self::Borrowed<'a>
fn borrow<'a>(&'a self) -> Self::Borrowed<'a>
Converts a reference to the type to a borrowed variant. Read more
Sourcefn reborrow<'b, 'a: 'b>(thing: Self::Borrowed<'a>) -> Self::Borrowed<'b>where
CV: 'a,
fn reborrow<'b, 'a: 'b>(thing: Self::Borrowed<'a>) -> Self::Borrowed<'b>where
CV: 'a,
Reborrows the borrowed type to a shorter lifetime. See
Columnar::reborrow for details.Sourcefn reborrow_ref<'b, 'a: 'b>(thing: Self::Ref<'a>) -> Self::Ref<'b>where
Self: 'a,
fn reborrow_ref<'b, 'a: 'b>(thing: Self::Ref<'a>) -> Self::Ref<'b>where
Self: 'a,
Reborrows the borrowed type to a shorter lifetime. See
Columnar::reborrow for details.Sourceimpl<CV: PushIndexAs<u32>> Container for Chars<CV>
impl<CV: PushIndexAs<u32>> Container for Chars<CV>
fn reserve_for<'a, I>(&mut self, selves: I)
Sourceimpl<'a, CV: FromBytes<'a>> FromBytes<'a> for Chars<CV>
impl<'a, CV: FromBytes<'a>> FromBytes<'a> for Chars<CV>
Sourceconst SLICE_COUNT: usize = CV::SLICE_COUNT
const SLICE_COUNT: usize = CV::SLICE_COUNT
The number of byte slices this type consumes when reconstructed.
Sourcefn from_bytes(bytes: &mut impl Iterator<Item = &'a [u8]>) -> Self
fn from_bytes(bytes: &mut impl Iterator<Item = &'a [u8]>) -> Self
Reconstructs
self from a sequence of correctly aligned and sized bytes slices. Read moreSourcefn from_store(store: &DecodedStore<'a>, offset: &mut usize) -> Self
fn from_store(store: &DecodedStore<'a>, offset: &mut usize) -> Self
Sourceimpl<CV: IndexAs<u32>> Index for &Chars<CV>
impl<CV: IndexAs<u32>> Index for &Chars<CV>
Sourceimpl<CV: IndexAs<u32>> Index for Chars<CV>
impl<CV: IndexAs<u32>> Index for Chars<CV>
impl<CV: Copy> Copy for Chars<CV>