pub struct Repeats<TC, CC = Vec<u64>, VC = Vec<u64>, WC = [u64; 2]> {
pub inner: Options<TC, CC, VC, WC>,
}Expand description
A container that encodes repeated values with a None variant, at the cost of extra bits for every record.
Fields
inner: Options<TC, CC, VC, WC>Some(x) encodes a value, and None indicates the prior x value.